#######################################################
#	
#	Metro Map Drawing Project
#
#	Date: 	18 Sep 2008
#
#	Language:	R
#
#######################################################
 
library(survBayes)
library(session)
library(foreign)

#######################################################
#	readging the data
#######################################################
MapTypeP <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MapType_P.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)
MapTypeG <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MapType_G.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)
MapTypeA <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MapType_A.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)

# mergging the data in a single object and defining factors
 attach(MapTypeG)     # Geo
 attach(MapTypeP)     # Pub
 attach(MapTypeA)     # Aut
 MetroMap_GPA <- rbind(MapTypeP, MapTypeA)
 MetroMap_GPA <- rbind(MetroMap_GPA, MapTypeG)
 
MetroMap_GPA[,"TypeG"] <- 0
MetroMap_GPA[,"TypeP"] <- 0
MetroMap_GPA[,"TypeA"] <- 0
MetroMap_GPA[MetroMap_GPA["MapType"] == "G","TypeG"] <- 1
MetroMap_GPA[MetroMap_GPA["MapType"] == "P","TypeP"] <- 1
MetroMap_GPA[MetroMap_GPA["MapType"] == "A","TypeA"] <- 1

write.csv(MetroMap_GPA, file = "E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MetroMap_GPA.csv", row.names = FALSE)

#######################################################
# COVARIATES and FRAILTIES
#######################################################
# Covariate:              1.  Map system (City)
#                         2.  MapType (releant)   
# 
# Clusters (frailties):   1.  Login (individuals)
######################################################
#L. Knorr-Held and H. Rue. On block updating in markov random field models for disease mapping. Scandinavian Journal of Statistics, 29:597614,2002.
#	Simultaneous analysis by Map-Type using frailties
#######################################################
library(survBayes)
library(session)
library(foreign)

MetroMap <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MetroMap_GPA.csv")
head(MetroMap) 
summary(MetroMap)

control <- survBayes.control(sigma.lbh.1 = 0.01, rate.sigma.lbh.1 = 0.001, shape.sigma.lbh.1 = 0.001)
control.frailty <- survBayes.control.gamma.frailty(mu.cl = 1, prec.tau.cl = 1e-04)

MetroMap.res <- survBayes(Surv(Time.s./10, CorrectCod, type = "right") 
      ~ as.factor(TypeP) + as.factor(TypeA) + as.factor(Map) + frailty(Login, dist = "gamma") ,
      data = MetroMap, 
      burn.in = 20000, 
      number.sample = 150000)

str(MetroMap.res)

save.session("E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/MetroMap__Out_08Sep18_final.Rda")

#######################################################
#	reading the data
#######################################################
library(survBayes)
library(session)
library(foreign)
library(psych)

MetroMap <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Data/MetroMap_GPA.csv")
head(MetroMap) 

# Statistics by group (MapType)
describe.by(MetroMap["Time.s."], MetroMap$MapType)

# Statistics by group (MapType) with "Correct" answers
describe.by(MetroMap[MetroMap["Correct"]==TRUE,"Time.s."], MetroMap[MetroMap["Correct"]==TRUE,]$MapType)
                                                        
# Statistics by group (MapType) with "Incorrect" answers
describe.by(MetroMap[MetroMap["Correct"]==FALSE,"Time.s."], MetroMap[MetroMap["Correct"]==FALSE,]$MapType)

#######################################################
#	Loading the output saved
#######################################################
library(survBayes)
library(session)
library(foreign)
library(psych)


load("E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/MetroMap__Out_08Sep18_final.Rda")
# Summary results
str(MetroMap.res)
  
summary(MetroMap.res$beta)
  
# Bayesian estimates of proportional hazard coefficients
beta.est <- apply(MetroMap.res$beta, 2, mean)
is.table(MetroMap.res$beta)
Betas.Path <- as.table(MetroMap.res$beta)
write.csv(Betas.Path, "E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/Betas.Path_08Sep18_final.csv")
Betas.Path <- read.csv("E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/Betas.Path_08Sep18_final.csv", row.names = 1)
names(Betas.Path) <- c("TypeP","TypeA","Map2","Map3","Map4","Map5","Map6")
head(Betas.Path)
Betas.Path["TypeAvsP"] <- Betas.Path["TypeA"] - Betas.Path["TypeP"]
Betas.Path[Betas.Path["TypeAvsP"] < 0,"ContrastAvsP"] <- 0
Betas.Path[Betas.Path["TypeAvsP"] >= 0,"ContrastAvsP"] <- 1
Betas.Path <- as.matrix(Betas.Path)

summary(Betas.Path[,c("TypeP","TypeA","TypeAvsP","ContrastAvsP")])
hist(Betas.Path[,c("TypeAvsP")], breaks = 50, col="lightblue", border="pink",xlab="Cotrast of beta_A vs beta_P", main="")
abline(v=0,lty=2)

write.csv(Betas.Path, "E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/Betas.Path_08Sep18_final.csv")

# Bayesian estimates of the survival function
baseline.hazard <- survBayes.baseline.hazard(MetroMap.res, start = 1, type = "cum", n.inter = 0)
time <- baseline.hazard$time
Lambda0 <- baseline.hazard$cum.base.haz
surv.base <- exp(-Lambda0)
plot(time, surv.base, type = "l", xlab = "Time [seconds/10]", ylab = "Survival function", xlim = c(0,10), lty = 1, ylim = c(0, 1))

save.session("E:/JCMO.PhD/Research/FrailtyMetroMaps/Code/MetroMap__Out_08Sep18_final.Rda")

#
#	--	END	--