#######################################################
#	
#	Metro Map Project
#
#	Date: 	Aug 31, 2007
#			Sep	02, 2007 
#			Sep 05, 2007 (latest revision)
#
#	Language:	R
#
#######################################################

#	(**)	Internet connection required
# install.packages("foreign")
# install.packages("survival")
# install.packages("session")
# install.packages("frailtypack")
 
library(foreign)
library(survival)
library(session)
library(frailtypack)

# 	updating packages
#
# update.packages(ask='graphics')

#######################################################
#	reading the data
#######################################################
MapTypeP <- read.csv("E:/Statistics.MetroMaps/Data/MapType_P.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)
MapTypeG <- read.csv("E:/Statistics.MetroMaps/Data/MapType_G.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)
MapTypeF <- read.csv("E:/Statistics.MetroMaps/Data/MapType_F.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)

# merging the data in a single object and defining factors
 attach(MapTypeP)
 attach(MapTypeG)
 attach(MapTypeF)
 MetroMap <- rbind(MapTypeP, MapTypeG)
 MetroMap <- rbind(MetroMap, MapTypeF)

 MapTypeP$Map <- as.factor(MapTypeP$Map)				#	Location of map
 MapTypeP$Qgrp <- as.factor(MapTypeP$Qgrp)				#	Group of individuals
 MapTypeP$Login <- as.factor(MapTypeP$Login)			#	Repeated observations of individuals

 MapTypeG$Map <- as.factor(MapTypeG$Map)				#	Location of map
 MapTypeG$Qgrp <- as.factor(MapTypeG$Qgrp)				#	Group of individuals
 MapTypeG$Login <- as.factor(MapTypeG$Login)			#	Repeated observations of individuals

 MapTypeF$Map <- as.factor(MapTypeF$Map)				#	Location of map
 MapTypeF$Qgrp <- as.factor(MapTypeF$Qgrp)				#	Group of individuals
 MapTypeF$Login <- as.factor(MapTypeF$Login)			#	Repeated observations of individuals

 MetroMap$Map <- as.factor(MetroMap$Map)				#	Location of map
 MetroMap$Qgrp <- as.factor(MetroMap$Qgrp)				#	Group of individuals
 MetroMap$Login <- as.factor(MetroMap$Login)			#	Repeated observations of individuals
 MetroMap$MapType <- as.factor(MetroMap$MapType)		#	Type of map
 
#######################################################
#	I. analysis for Map Type P
#######################################################
 MetroMap.P.Surv <- frailtyPenal(Surv(Time.s.,Correct) ~ Map + cluster(Login), n.knots=13, kappa1=1000, data=MapTypeP, cross.validation=TRUE, Frail=TRUE)
 
 print.frailtyPenal(MetroMap.P.Surv)
 
 summary.frailtyPenal(MetroMap.P.Surv,level = 0.95, len = 6)

 plot(MetroMap.P.Surv, type="surv", conf=FALSE)

#######################################################
#	I. analysis for Map Type G
#######################################################
 MetroMap.G.Surv <- frailtyPenal(Surv(Time.s.,Correct) ~ Map + cluster(Login), n.knots=13, kappa1=1000, data=MapTypeG, cross.validation=TRUE, Frail=TRUE)
 
 print.frailtyPenal(MetroMap.G.Surv)
 
 summary.frailtyPenal(MetroMap.G.Surv,level = 0.95, len = 6)

 lines(MetroMap.G.Surv, type="surv", conf=FALSE)

#######################################################
#	I. analysis for Map Type F
#######################################################
 MetroMap.F.Surv <- frailtyPenal(Surv(Time.s.,Correct) ~ Map + cluster(Login), n.knots=13, kappa1=1000, data=MapTypeF, cross.validation=TRUE, Frail=TRUE)
 
 print.frailtyPenal(MetroMap.F.Surv)
 
 summary.frailtyPenal(MetroMap.F.Surv,level = 0.95, len = 6)

 lines(MetroMap.F.Surv, type="surv", conf=FALSE)

#######################################################
#	II. analysis with aggregated and grouped data
#######################################################
 MetroMap.Surv <- frailtyPenal(Surv(Time.s.,Correct) ~ Map + cluster(Login) + MapType, n.knots=10, kappa1=1000, data=MetroMap, cross.validation=TRUE, Frail=TRUE)
 
 print.frailtyPenal(MetroMap.Surv)
 
 summary.frailtyPenal(MetroMap.Surv,level = 0.95, len = 6)

 plot(MetroMap.Surv, type="surv", conf=TRUE)

#######################################################
#	II. analysis with aggregated and grouped data
#######################################################

 MetroMap.Surv <- frailtyPenal(Surv(Time.s.,Correct) ~ Map + cluster(Login) + MapType, n.knots=10, kappa1=1000, data=MetroMap, cross.validation=TRUE, Frail=TRUE)
 
 print.frailtyPenal(MetroMap.Surv)
 
 summary.frailtyPenal(MetroMap.Surv,level = 0.95, len = 6)

 plot(MetroMap.Surv, type="surv", conf=TRUE)
 
#######################################################
# 	Saving and reading the output
#######################################################
save.session("E:/Statistics.MetroMaps/Code/MetroMap__Out_04Sep.Rda")

q("no")

#######################################################
#	Loading the output saved
#######################################################
library(session)
load("E:/Statistics.MetroMaps/Code/MetroMap_Out_04Sep.Rda")

#
#	--	END	--