# Comments
# Command lines (copy to the console window)
# Output (do not copy to the console window)

# Loading some libraries

library(foreign)
library(survival)

# Updating packages

update.packages(ask='graphics')

# Importing the data

GroupA <- read.csv("/home/jms/animal/thesis/stats/Group_A.csv", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)

GroupB <- read.csv("F:/Statistics.Rodgers/Data/Group_B.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)

GroupC <- read.csv("F:/Statistics.Rodgers/Data/Group_C.CSV", header = TRUE, sep = ",", quote="\"", dec=".", fill = TRUE)

attach(GroupA)
attach(GroupB)
attach(GroupC)

# Working with group A

summary(GroupA)

     Login     Qgrp         Map      Qu           X       MapType      Qseq      
 ad241  : 24   A:312   Min.   :1.0   a:78   Min.   :0.0   F:104   Min.   : 5.00  
 as304  : 24           1st Qu.:2.0   b:78   1st Qu.:0.0   G:104   1st Qu.:10.75  
 asg4   : 24           Median :3.5   c:78   Median :0.5   P:104   Median :16.50  
 cav3   : 24           Mean   :3.5   d:78   Mean   :0.5           Mean   :16.50  
 cg79   : 24           3rd Qu.:5.0          3rd Qu.:1.0           3rd Qu.:22.25  
 cw89   : 24           Max.   :6.0          Max.   :1.0           Max.   :28.00  
 (Other):168                                                                     
     ActAns          TheirAns       Correct          CorrectCod          Ease      
 Min.   : 0.000   Min.   : 0.000   Mode :logical   Min.   :0.0000   Min.   :0.000  
 1st Qu.: 1.000   1st Qu.: 1.000   FALSE:82        1st Qu.:0.0000   1st Qu.:1.000  
 Median : 2.000   Median : 2.000   TRUE :230       Median :1.0000   Median :2.000  
 Mean   : 4.042   Mean   : 3.885                   Mean   :0.7372   Mean   :1.817  
 3rd Qu.: 6.250   3rd Qu.: 6.000                   3rd Qu.:1.0000   3rd Qu.:2.000  
 Max.   :14.000   Max.   :13.000                   Max.   :1.0000   Max.   :4.000  
                                                                                   
    Time.ms.        Time.s.     
 Min.   : 4438   Min.   : 4.44  
 1st Qu.:12090   1st Qu.:12.09  
 Median :15891   Median :15.89  
 Mean   :19740   Mean   :19.74  
 3rd Qu.:25139   3rd Qu.:25.14  
 Max.   :79264   Max.   :79.26  
# Linear regression

#	Working with data from Group A

plot(GroupA$Time.s,GroupA$MapType)

plot(GroupA$Time.s,GroupA$Correct)

#	Fitting a linear model
#	Model:		log(Time.s) = b0 + b1 * Map.Type + b2 * Correct + error
#			error ~ N(0,StDev)

lm.GA <- lm(log(GroupA$Time.s) ~ GroupA$MapType + GroupA$Correct)

lm.GA


Call:
lm(formula = log(GroupA$Time.s) ~ GroupA$MapType + GroupA$Correct)

Coefficients:
       (Intercept)     GroupA$MapTypeG     GroupA$MapTypeP  GroupA$CorrectTRUE  
           2.78935             0.14028             0.18266            -0.05675  

# R converted the covariates in dichotomous variables, and define the model in terms of the first k-1 components of each category.
# The above coefficients are the correspondent components for those dichotomous variables
summary(lm.GA)

Call:
lm(formula = log(GroupA$Time.s) ~ GroupA$MapType + GroupA$Correct)

Residuals:
    Min      1Q  Median      3Q     Max 
-1.2419 -0.3582 -0.1034  0.3132  1.4696 

Coefficients:
                   Estimate Std. Error t value Pr(>|t|)    
(Intercept)         2.78935    0.07152  39.001  < 2e-16 ***
GroupA$MapTypeG     0.14028    0.06919   2.028  0.04347 *  
GroupA$MapTypeP     0.18266    0.06729   2.715  0.00701 ** 
GroupA$CorrectTRUE -0.05675    0.06458  -0.879  0.38022    
---
Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

Residual standard error: 0.4851 on 308 degrees of freedom
Multiple R-Squared: 0.02958,    Adjusted R-squared: 0.02012 
F-statistic: 3.129 on 3 and 308 DF,  p-value: 0.02601 

# The above output summarizes the estimation procedure. In the block "coefficients" you will find the correspondent parameter estimates, again, and their statistics to evaluate its significance. The last block corresponds to the significance of the model. I will explain you how to interpret those results...

plot(lm.GA)

# I'll explain to you how to read this plots also

# Generalized linear models

#	Fitting a generalized linear model
#	This time, is assumed that  “Time.s” follows a Gamma distribution
#	This is the case of the generlized “gamma” linear model, 
#	using the cannonical link function (which could not be convenient, i will explain the reason later)
#	Model:		E(Time.s) = (b0 + b1 * Map.Type + b2 * Correct)-1
#

glm.GA <- glm(GroupA$Time.s ~ MapType + Correct, data=GroupA, family=Gamma)

glm.GA

Call:  glm(formula = GroupA$Time.s ~ MapType + Correct, family = Gamma,      data = GroupA) 

Coefficients:
(Intercept)     MapTypeG     MapTypeP  CorrectTRUE  
   0.054356    -0.005443    -0.008406     0.001579  

Degrees of Freedom: 311 Total (i.e. Null);  308 Residual
Null Deviance:      79.58 
Residual Deviance: 78.07        AIC: 2258 

#	AIC is a measure-value criteria to evaluate the model fit. I will give you details about it, because you will use it to validate your future model.

summary(glm.GA)

Call:
glm(formula = GroupA$Time.s ~ MapType + Correct, family = Gamma, 
    data = GroupA)

Deviance Residuals: 
    Min       1Q   Median       3Q      Max  
-1.1325  -0.4488  -0.2205   0.2207   1.6975  

Coefficients:
             Estimate Std. Error t value Pr(>|t|)    
(Intercept)  0.054356   0.004344  12.514   <2e-16 ***
MapTypeG    -0.005443   0.004248  -1.281   0.2011    
MapTypeP    -0.008406   0.004045  -2.078   0.0385 *  
CorrectTRUE  0.001579   0.003737   0.423   0.6729    
---
Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

(Dispersion parameter for Gamma family taken to be 0.3193106)

    Null deviance: 79.576  on 311  degrees of freedom
Residual deviance: 78.071  on 308  degrees of freedom
AIC: 2257.8

Number of Fisher Scoring iterations: 5

plot(glm.GA)

#	Even when you can fit this kind of models, it is not really appropriate. We will discuss that with more detail, and the reason why survival models are more convenient
# Survival models
# Pendent...